# Django
from django.urls import include, path, re_path

# Local
from .views import account, socialaccount

urlpatterns = [
    path("login/", account.login, name="account_login",),
    path("signup/", account.signup, name="account_signup",),
    path("password/change/", account.password_change, name="account_change_password",),
    path("password/set/", account.password_set, name="account_set_password",),
    path("password/reset/", account.password_reset, name="account_reset_password",),
    re_path(
        r"^password/reset/key/(?P<uidb36>[0-9A-Za-z]+)-(?P<key>.+)/$",
        account.password_reset_from_key,
        name="account_reset_password_from_key",
    ),
    path("email/", account.email, name="account_email",),
    path("social/signup/", socialaccount.signup, name="socialaccount_signup",),
    path("", include("allauth.urls")),
]



# Third Party Libraries
from allauth.account import views as account_views
from turbo_response.mixins import TurboFormAdapterMixin


class LoginView(TurboFormAdapterMixin, account_views.LoginView):
    ...


login = LoginView.as_view()


class SignupView(TurboFormAdapterMixin, account_views.SignupView):
    ...


signup = SignupView.as_view()


class EmailView(TurboFormAdapterMixin, account_views.EmailView):
    ...


email = EmailView.as_view()


class PasswordChangeView(TurboFormAdapterMixin, account_views.PasswordChangeView):
    ...


password_change = PasswordChangeView.as_view()


class PasswordSetView(TurboFormAdapterMixin, account_views.PasswordSetView):
    ...


password_set = PasswordSetView.as_view()


class PasswordResetView(TurboFormAdapterMixin, account_views.PasswordResetView):
    ...


password_reset = PasswordResetView.as_view()


class PasswordResetFromKeyView(
    TurboFormAdapterMixin, account_views.PasswordResetFromKeyView
):
    ...


password_reset_from_key = PasswordResetFromKeyView.as_view()



# Third Party Libraries
from allauth.socialaccount import views as socialaccount_views
from turbo_response.mixins import TurboFormAdapterMixin


class SignupView(TurboFormAdapterMixin, socialaccount_views.SignupView):
    ...


signup = SignupView.as_view()
